@@ -140,7 +140,6 @@ desktop_clock_widget_load_svg_file(const gchar* path,
 static void
 desktop_clock_widget_free_svg_theme(DesktopClockSVGTheme* theme)
 {
-  g_warning("free svg\n");
   if(theme->drop_shadow)
   {
     g_object_unref(theme->drop_shadow);
@@ -192,7 +191,6 @@ desktop_clock_widget_free_svg_theme(DesktopClockSVGTheme* theme)
   if(theme->path)
     g_free(theme->path);
   g_free(theme);
-  g_warning("done \n");
 }
 
 static gboolean
@@ -289,6 +287,9 @@ desktop_clock_widget_render_foreground(cairo_t* main_cr,
   cairo_destroy(cr);
 }
 
+static void
+desktop_clock_widget_register_time_out_handler(DesktopClockWidgetHomePlugin* desktop_plugin);
+
 static gboolean
 desktop_clock_widget_update_time(gpointer data)
 {
@@ -301,7 +302,13 @@ desktop_clock_widget_update_time(gpointer data)
   gdk_threads_enter();
   gtk_widget_queue_draw(GTK_WIDGET(data));
   gdk_threads_leave();
-  return TRUE;
+  if(DESKTOP_CLOCK_WIDGET_HOME_PLUGIN(data)->priv->show_seconds)
+    return TRUE;
+  else
+  {
+    desktop_clock_widget_register_time_out_handler(DESKTOP_CLOCK_WIDGET_HOME_PLUGIN(data));
+    return FALSE;
+  }
 }
 
 static void
@@ -501,7 +508,6 @@ desktop_clock_widget_register_time_out_handler(DesktopClockWidgetHomePlugin* des
 static void
 desktop_clock_widget_init_theme(DesktopClockWidgetHomePlugin* desktop_plugin)
 {
-  g_warning("init_theme\n");
   DesktopClockSVGTheme* theme = g_new0(DesktopClockSVGTheme, 1);
   if(desktop_plugin->priv->use_stock_theme || desktop_plugin->priv->theme_path==NULL)
   {
@@ -552,7 +558,6 @@ desktop_clock_widget_init_theme(DesktopClockWidgetHomePlugin* desktop_plugin)
     g_object_ref(desktop_plugin->priv->second_shadow_svg_handle);
     desktop_clock_widget_free_svg_theme(theme);
   }
-  g_warning("init_theme done\n");
 }
 
 static int
@@ -654,7 +659,6 @@ desktop_clock_widget_select_theme(GtkButton* button, gpointer data)
       g_free(theme->path);
       theme->path = NULL;
       hildon_banner_show_information(NULL, NULL, "No theme files found");
-      g_warning("cannot read theme\n");
     }
     g_free(filename);
   }
@@ -1011,6 +1015,8 @@ desktop_clock_widget_on_current_desktop(GtkWidget* widget,
     {
       desktop_clock_widget_register_time_out_handler(desktop_plugin);
     }
+    if(!desktop_plugin->priv->show_seconds)
+      gtk_widget_queue_draw(GTK_WIDGET(desktop_plugin));
   }
   else
   {
